Package: tidyfst
Title: Tidy Verbs for Fast Data Manipulation
Version: 1.8.4
Depends: R (>= 4.1.0)
Authors@R: 
    person(given = "Tian-Yuan",
           family = "Huang",
           role = c("aut", "cre"),
           email = "huang.tian-yuan@qq.com",
           comment = c(ORCID = "0000-0002-4151-3764"))
Description: A toolkit of tidy data manipulation verbs with 'data.table' as the backend.
  Combining the merits of syntax elegance from 'dplyr' and computing performance from 'data.table', 
  'tidyfst' intends to provide users with state-of-the-art data manipulation tools with least pain.
  This package is an extension of 'data.table'. While enjoying a tidy syntax, 
  it also wraps combinations of efficient functions to facilitate frequently-used data operations.  
URL: https://github.com/hope-data-science/tidyfst,
        https://hope-data-science.github.io/tidyfst/
BugReports: https://github.com/hope-data-science/tidyfst/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: data.table (>= 1.15.0), fst (>= 0.9.0), stringr (>= 1.5.0),
        pak
Suggests: knitr, rmarkdown, nycflights13, tidyr, ggplot2, dplyr, bench,
        testthat, tidytext
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-27 06:39:15 UTC; Admin
Author: Tian-Yuan Huang [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4151-3764>)
Maintainer: Tian-Yuan Huang <huang.tian-yuan@qq.com>
Repository: CRAN
Date/Publication: 2026-04-27 07:00:02 UTC
