# Generated by roxygen2: do not edit by hand

export("%>%")
export("%chin%")
export("%like%")
export(CJ)
export(add_count_dt)
export(add_prop)
export(anti_join_dt)
export(arrange_dt)
export(as.data.table)
export(as_dt)
export(as_fst)
export(between)
export(bind_rows_dt)
export(bind_tf_idf_dt)
export(chop_dt)
export(col_max)
export(col_min)
export(col_rn)
export(complete_dt)
export(copy)
export(count_dt)
export(cummean)
export(data.table)
export(delete_na_cols)
export(delete_na_rows)
export(df_mat)
export(distinct_dt)
export(drop_na_dt)
export(dummy_dt)
export(export_fst)
export(fcase)
export(fcoalesce)
export(fill_na_dt)
export(filter_dt)
export(filter_fst)
export(fintersect)
export(fread)
export(frollapply)
export(fsetdiff)
export(fsetequal)
export(full_join_dt)
export(funion)
export(fwrite)
export(get_fst_chunk_size)
export(group_by_dt)
export(group_dt)
export(group_exe_dt)
export(import_fst)
export(import_fst_chunked)
export(impute_dt)
export(in_dt)
export(inner_join_dt)
export(intersect_dt)
export(key)
export(lag_dt)
export(lead_dt)
export(left_join_dt)
export(like)
export(longer_dt)
export(mat_df)
export(maxth)
export(minth)
export(mutate_dt)
export(mutate_vars)
export(mutate_when)
export(nest_dt)
export(nth)
export(object_size)
export(pairwise_count_dt)
export(parse_fst)
export(percent)
export(pkg_load)
export(pkg_unload)
export(print_options)
export(pst)
export(pull_dt)
export(rbindlist)
export(rec_char)
export(rec_num)
export(relocate_dt)
export(rename_dt)
export(rename_with_dt)
export(replace_dt)
export(replace_na_dt)
export(right_join_dt)
export(rleid)
export(rleidv)
export(rn_col)
export(round0)
export(rowwise_dt)
export(sample_dt)
export(sample_frac_dt)
export(sample_n_dt)
export(select_dt)
export(select_fst)
export(select_mix)
export(semi_join_dt)
export(separate_dt)
export(set)
export(setDF)
export(setDT)
export(setdiff_dt)
export(setequal_dt)
export(setnames)
export(shift_fill)
export(slice_dt)
export(slice_fst)
export(slice_head_dt)
export(slice_max_dt)
export(slice_min_dt)
export(slice_sample_dt)
export(slice_tail_dt)
export(sql_join_dt)
export(squeeze_dt)
export(summarise_dt)
export(summarise_vars)
export(summarise_when)
export(summarize_dt)
export(summarize_vars)
export(summarize_when)
export(summary_fst)
export(sys_time_print)
export(t_dt)
export(tables)
export(transmute_dt)
export(unchop_dt)
export(uncount_dt)
export(union_dt)
export(uniqueN)
export(unite_dt)
export(unnest_dt)
export(utf8_encoding)
export(wider_dt)
import(data.table)
import(fst)
import(stringr)
importFrom(data.table,"%chin%")
importFrom(data.table,"%like%")
importFrom(data.table,CJ)
importFrom(data.table,as.data.table)
importFrom(data.table,between)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,fcase)
importFrom(data.table,fcoalesce)
importFrom(data.table,fintersect)
importFrom(data.table,fread)
importFrom(data.table,frollapply)
importFrom(data.table,fsetdiff)
importFrom(data.table,fsetequal)
importFrom(data.table,funion)
importFrom(data.table,fwrite)
importFrom(data.table,key)
importFrom(data.table,like)
importFrom(data.table,rbindlist)
importFrom(data.table,rleid)
importFrom(data.table,rleidv)
importFrom(data.table,set)
importFrom(data.table,setDF)
importFrom(data.table,setDT)
importFrom(data.table,setnames)
importFrom(data.table,tables)
importFrom(data.table,uniqueN)
importFrom(pak,pak)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
importFrom(utils,object.size)
importFrom(utils,tail)
