
#' @import data.table
#' @import fst
#' @import stringr
#' @importFrom stats na.omit setNames median
#' @importFrom utils object.size head tail install.packages installed.packages
#' @importFrom pak pak

#' @export
stringr::`%>%`

#' @export
data.table::`%like%`

#' @export
data.table::`%chin%`

#' @export
data.table::data.table

#' @export
data.table::as.data.table

#' @export
data.table::fread

#' @export
data.table::fwrite

#' @export
data.table::fintersect

#' @export
data.table::fsetdiff

#' @export
data.table::funion

#' @export
data.table::fsetequal

#' @export
data.table::frollapply

#' @export
data.table::fcoalesce

#' @export
data.table::uniqueN

#' @export
data.table::rbindlist

#' @export
data.table::tables

#' @export
data.table::like

#' @export
data.table::copy

#' @export
data.table::key

#' @export
data.table::CJ

#' @export
data.table::rleid

#' @export
data.table::rleidv

#' @export
data.table::fcase

#' @export
data.table::between

#' @export
data.table::set

#' @export
data.table::setDT

#' @export
data.table::setDF

#' @export
data.table::setnames
