% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/arrange_dt.R
\name{arrange_dt}
\alias{arrange_dt}
\title{Arrange entries in data.frame}
\usage{
arrange_dt(.data, ...)
}
\arguments{
\item{.data}{data.frame}

\item{...}{Arrange by what group? Minus symbol means arrange by
descending order.}
}
\value{
data.table
}
\description{
Order the rows of a data frame rows by the values of selected columns.
}
\examples{

iris \%>\% arrange_dt(Sepal.Length)

# minus for decreasing order
iris \%>\% arrange_dt(-Sepal.Length)

# arrange by multiple variables
iris \%>\% arrange_dt(Sepal.Length,Petal.Length)

}
\seealso{
\code{\link[dplyr]{arrange}}
}
